@@ -5,7 +5,7 @@ context("tuple")
 test_that("construction",{
   expect_silent(Tuple$new(1,2,3))
   expect_silent(Tuple$new(1,2,3,1))
-  expect_silent(Tuple$new("A",TRUE,function(x) x^2, as.factor("a")))
+  expect_silent(Tuple$new("A",TRUE, as.factor("a")))
   expect_silent(Tuple$new(1+0i,2,2L,5.67))
   expect_silent(Tuple$new(1:10))
   expect_silent(Tuple$new(list(a=1)))
@@ -61,8 +61,8 @@ test_that("isSubset",{
   expect_true(Tuple$new(1,2,3)$isSubset(FuzzySet$new(elements = 1:2)))
   expect_true(Tuple$new(1,2,3)$isSubset(Tuple$new(1,2), proper = TRUE))
   expect_true(Tuple$new(1,2,3)$isSubset(Set$new(1,2,3)))
-  expect_false(Tuple$new(1)$isSubset(Tuple$new(1:2)))
-  expect_false(Tuple$new(1:2)$isSubset(Tuple$new(3:4)))
+  expect_false(Tuple$new(1)$isSubset(Tuple$new(elements = 1:2)))
+  expect_false(Tuple$new(elements = 1:2)$isSubset(Tuple$new(elements = 3:4)))
   expect_false(Tuple$new(1,2,3)$isSubset(Tuple$new(4)))
   expect_false(Tuple$new(1,2,3)$isSubset(4))
   expect_false(Tuple$new(1,2,3)$isSubset(FuzzySet$new(1,0.5)))
@@ -76,10 +76,10 @@ test_that("isSubset",{
 
 test_that("as.Tuple",{
   expect_equal(as.Tuple(c(1,2)), Tuple$new(1,2))
-  expect_equal(as.Tuple(list(1:2,2)), list(Tuple$new(1:2), Tuple$new(2)))
+  expect_equal(as.Tuple(list(1:2,2)), list(Tuple$new(elements = 1:2), Tuple$new(2)))
   expect_equal(as.Tuple(matrix(c(1,2,3,4),nrow = 2)), list(Tuple$new(1,2),Tuple$new(3,4)))
   expect_equal(as.Tuple(FuzzySet$new(1, 0.1, 2, 0.2)), Tuple$new(1, 2))
-  expect_equal(as.Tuple(Set$new(1:5)), Tuple$new(1:5))
+  expect_equal(as.Tuple(Set$new(elements = 1:5)), Tuple$new(elements = 1:5))
   expect_error(expect_equal(as.Tuple(Interval$new()), Interval$new()),"Interval cannot")
   expect_error(expect_equal(as.Tuple(ConditionalSet$new(function(x) TRUE)), ConditionalSet$new(function(x) TRUE)), "ConditionalSet cannot be")
 })
